.. _user_guide:

==========
User guide
==========

.. note::
  You can download the `user guide and examples <https://codeload.github.com/nilearn/nilearn.github.io/zip/refs/heads/main>`_
  for offline viewing.

This user guide is especially directed towards grad students
with a background in computer science, machine learning,
computational biology or neuroscience.
However, less or more advanced readers can also find interesting
pieces of information throughout the guide.

Table of contents
=================

.. toctree::
   :numbered:
   :maxdepth: 3

   introduction.rst
   decoding/index.rst
   connectivity/index.rst
   plotting/index.rst
   glm/index.rst
   manipulating_images/index.rst
   building_blocks/index.rst
